Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r83222 - sandbox/contract/boost/contract
From: lorcaminiti_at_[hidden]
Date: 2013-02-28 20:00:24


Author: lcaminiti
Date: 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
New Revision: 83222
URL: http://svn.boost.org/trac/boost/changeset/83222

Log:
Renaming symbols adding boost prefixes.
Text files modified:
   sandbox/contract/boost/contract/block_invariant.hpp | 39 ++++++++--------
   sandbox/contract/boost/contract/body.hpp | 65 ++++++++++++++-------------
   sandbox/contract/boost/contract/broken.hpp | 10 ++--
   sandbox/contract/boost/contract/class.hpp | 33 +++++++-------
   sandbox/contract/boost/contract/class_invariant.hpp | 47 ++++++++++----------
   sandbox/contract/boost/contract/config.hpp | 54 +++++++++++-----------
   sandbox/contract/boost/contract/constructor.hpp | 48 ++++++++++----------
   sandbox/contract/boost/contract/copy.hpp | 8 +-
   sandbox/contract/boost/contract/destructor.hpp | 48 ++++++++++----------
   sandbox/contract/boost/contract/function.hpp | 48 ++++++++++----------
   sandbox/contract/boost/contract/limits.hpp | 17 +++---
   sandbox/contract/boost/contract/loop_variant.hpp | 55 ++++++++++++-----------
   sandbox/contract/boost/contract/oldof.hpp | 15 +++---
   sandbox/contract/boost/contract/parameter.hpp | 91 +++++++++++++++++++++------------------
   14 files changed, 299 insertions(+), 279 deletions(-)

Modified: sandbox/contract/boost/contract/block_invariant.hpp
==============================================================================
--- sandbox/contract/boost/contract/block_invariant.hpp (original)
+++ sandbox/contract/boost/contract/block_invariant.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,16 +5,16 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_BLOCK_INVARIANT_HPP_
-#define CONTRACT_BLOCK_INVARIANT_HPP_
+#ifndef BOOST_CONTRACT_BLOCK_INVARIANT_HPP_
+#define BOOST_CONTRACT_BLOCK_INVARIANT_HPP_
 
 /** @file
 @brief Macros used to specify block invariants (this header is automatically
 included by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/macro/block_invariant.hpp>
-#include <contract/detail/preprocessor/variadic/to_seq.hpp>
+#include <boost/contract/aux_/macro/block_invariant.hpp>
+#include <boost/contract/detail/preprocessor/variadic/to_seq.hpp>
 #include <boost/local_function/detail/preprocessor/line_counter.hpp>
 #include <boost/config.hpp>
 
@@ -22,30 +22,30 @@
 
 #ifndef BOOST_NO_VARIADIC_MACROS
 
-#define CONTRACT_BLOCK_INVARIANT(...) \
- CONTRACT_AUX_BLOCK_INVARIANT( \
+#define BOOST_CONTRACT_BLOCK_INVARIANT(...) \
+ BOOST_CONTRACT_AUX_BLOCK_INVARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0, /* outside template */ \
- CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ( \
+ BOOST_CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ( \
                     (ERROR_block_invariants_cannot_be_empty), __VA_ARGS__))
 
-#define CONTRACT_BLOCK_INVARIANT_TPL(...) \
- CONTRACT_AUX_BLOCK_INVARIANT( \
+#define BOOST_CONTRACT_BLOCK_INVARIANT_TPL(...) \
+ BOOST_CONTRACT_AUX_BLOCK_INVARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1, /* inside template */ \
- CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ( \
+ BOOST_CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ( \
                     (ERROR_block_invariants_cannot_be_empty), __VA_ARGS__))
 
 #else
 
-#define CONTRACT_BLOCK_INVARIANT(seq) \
- CONTRACT_AUX_BLOCK_INVARIANT( \
+#define BOOST_CONTRACT_BLOCK_INVARIANT(seq) \
+ BOOST_CONTRACT_AUX_BLOCK_INVARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0, /* outside template */ \
             seq)
 
-#define CONTRACT_BLOCK_INVARIANT_TPL(seq) \
- CONTRACT_AUX_BLOCK_INVARIANT( \
+#define BOOST_CONTRACT_BLOCK_INVARIANT_TPL(seq) \
+ BOOST_CONTRACT_AUX_BLOCK_INVARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1, /* inside template */ \
             seq)
@@ -70,22 +70,23 @@
 @EndParams
 
 Within a type-dependent scope (e.g., within templates),
-_at_RefMacro{CONTRACT_BLOCK_INVARIANT_TPL} must be used instead of this macro.
+@RefMacro{BOOST_CONTRACT_BLOCK_INVARIANT_TPL} must be used instead of this
+macro.
 
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
-#define CONTRACT_BLOCK_INVARIANT(assertions)
+#define BOOST_CONTRACT_BLOCK_INVARIANT(assertions)
 
 /**
 @brief Macro used to specify block invariants within a type-dependent scope
 (e.g., within templates).
 
-This macro is the exact same as @RefMacro{CONTRACT_BLOCK_INVARIANT} but is must
-be used when specifying block invariants within a type-dependent scope.
+This macro is the exact same as @RefMacro{BOOST_CONTRACT_BLOCK_INVARIANT} but
+it must be used when specifying block invariants within a type-dependent scope.
 
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
-#define CONTRACT_BLOCK_INVARIANT_TPL(assertions)
+#define BOOST_CONTRACT_BLOCK_INVARIANT_TPL(assertions)
 
 #endif
 

Modified: sandbox/contract/boost/contract/body.hpp
==============================================================================
--- sandbox/contract/boost/contract/body.hpp (original)
+++ sandbox/contract/boost/contract/body.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,26 +5,26 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_BODY_HPP_
-#define CONTRACT_BODY_HPP_
+#ifndef BOOST_CONTRACT_BODY_HPP_
+#define BOOST_CONTRACT_BODY_HPP_
 
 /** @file
 @brief Macros used to program body definitions separately from the contract
 declarations (this header is automatically include by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/config.hpp>
-#include <contract/aux_/symbol.hpp>
-#include <contract/aux_/macro/body.hpp>
+#include <boost/contract/aux_/config.hpp>
+#include <boost/contract/aux_/symbol.hpp>
+#include <boost/contract/aux_/macro/body.hpp>
 
 // PRIVATE //
 
 #ifndef DOXYGEN
 
-#define CONTRACT_BODY_CTOR_DTOR_( \
+#define BOOST_CONTRACT_BODY_CTOR_DTOR_( \
         contracted_body_macro, class_type, constructor_name, contracted01) \
     BOOST_PP_EXPR_IF(contracted01, void) \
- CONTRACT_AUX_BODY_CLASS_TYPE(class_type) :: \
+ BOOST_CONTRACT_AUX_BODY_CLASS_TYPE(class_type) :: \
     BOOST_PP_IIF(contracted01, \
         contracted_body_macro \
     , \
@@ -42,7 +42,7 @@
 This macro is used to name the body of free functions and free function
 operators when the body is defined separately from the contract declaration.
 Free functions and free function operators with contracts are declared
-using the @RefMacro{CONTRACT_FUNCTION} macro.
+using the @RefMacro{BOOST_CONTRACT_FUNCTION} macro.
 
 @Params
 @Param{function_name,
@@ -53,15 +53,15 @@
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_FREE_BODY(function_name) \
+#define BOOST_CONTRACT_FREE_BODY(function_name) \
     BOOST_PP_IIF( \
             BOOST_PP_BITOR( \
- CONTRACT_AUX_CONFIG_PRECONDITIONS_01 \
- , CONTRACT_AUX_CONFIG_POSTCONDITIONS_01 \
+ BOOST_CONTRACT_AUX_CONFIG_PRECONDITIONS_01 \
+ , BOOST_CONTRACT_AUX_CONFIG_POSTCONDITIONS_01 \
             ), \
- CONTRACT_AUX_BODY_FUNCTION_CONTRACTED \
+ BOOST_CONTRACT_AUX_BODY_FUNCTION_BOOST_CONTRACTED \
     , \
- CONTRACT_AUX_BODY_FUNCTION \
+ BOOST_CONTRACT_AUX_BODY_FUNCTION \
     )(function_name)
 
 /**
@@ -71,7 +71,7 @@
 This macro is used to name the body of member functions and member function
 operators when the body is defined separately from the contract declaration.
 Member functions and member function operators with contracts are declared
-using the @RefMacro{CONTRACT_FUNCTION} macro.
+using the @RefMacro{BOOST_CONTRACT_FUNCTION} macro.
 
 @Params
 @Param{function_name,
@@ -86,21 +86,21 @@
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_MEMBER_BODY(function_name) \
+#define BOOST_CONTRACT_MEMBER_BODY(function_name) \
     /* NOTE: this must be a different macro from FREE_BODY because it */ \
     /* expands also if invariants (not just pre and post) */ \
     /* class type is specified so this macro API is same as ctor and dtor */ \
     BOOST_PP_IIF( \
             BOOST_PP_BITOR( \
- CONTRACT_AUX_CONFIG_PRECONDITIONS_01 \
+ BOOST_CONTRACT_AUX_CONFIG_PRECONDITIONS_01 \
                 , BOOST_PP_BITOR( \
- CONTRACT_AUX_CONFIG_POSTCONDITIONS_01 \
- , CONTRACT_AUX_CONFIG_CLASS_INVARIANTS_01 \
+ BOOST_CONTRACT_AUX_CONFIG_POSTCONDITIONS_01 \
+ , BOOST_CONTRACT_AUX_CONFIG_CLASS_INVARIANTS_01 \
                   ) \
             ), \
- CONTRACT_AUX_BODY_FUNCTION_CONTRACTED \
+ BOOST_CONTRACT_AUX_BODY_FUNCTION_BOOST_CONTRACTED \
     , \
- CONTRACT_AUX_BODY_FUNCTION \
+ BOOST_CONTRACT_AUX_BODY_FUNCTION \
     )(function_name)
 
 /**
@@ -109,12 +109,13 @@
 This macro is used to name the body of constructors when the body is defined
 separately from the contract declaration.
 Constructors with contracts are declared using the
-_at_RefMacro{CONTRACT_CONSTRUCTOR} macro.
+@RefMacro{BOOST_CONTRACT_CONSTRUCTOR} macro.
 
 @Params
 @Param{class_type,
 The syntax for the class type is explained in the @RefSect{grammar\, Grammar}
-section (for class templates\, this type is qualified with the template parameters).
+section (for class templates\, this type is qualified with the template
+parameters).
 }
 @Param{constructor_name,
 This is the class name and its syntax is explained in the
@@ -129,14 +130,15 @@
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
 // class_type: `vect<T>`, `(vect<T, A>)`, or `comma(1)(vect<T, A>)`.
-#define CONTRACT_CONSTRUCTOR_BODY(class_type, constructor_name) \
- CONTRACT_BODY_CTOR_DTOR_(CONTRACT_AUX_BODY_CONSTRUCTOR_CONTRACTED \
+#define BOOST_CONTRACT_CONSTRUCTOR_BODY(class_type, constructor_name) \
+ BOOST_CONTRACT_BODY_CTOR_DTOR_( \
+ BOOST_CONTRACT_AUX_BODY_CONSTRUCTOR_BOOST_CONTRACTED \
         , class_type, constructor_name \
         , BOOST_PP_BITOR( \
- CONTRACT_AUX_CONFIG_PRECONDITIONS_01 \
+ BOOST_CONTRACT_AUX_CONFIG_PRECONDITIONS_01 \
             , BOOST_PP_BITOR( \
- CONTRACT_AUX_CONFIG_POSTCONDITIONS_01 \
- , CONTRACT_AUX_CONFIG_CLASS_INVARIANTS_01 \
+ BOOST_CONTRACT_AUX_CONFIG_POSTCONDITIONS_01 \
+ , BOOST_CONTRACT_AUX_CONFIG_CLASS_INVARIANTS_01 \
               ) \
           ) \
     )
@@ -147,7 +149,7 @@
 This macro is used to name the body of destructors when the body is defined
 separately from the contract declaration.
 Destructors with contracts are declared using the
-_at_RefMacro{CONTRACT_DESTRUCTOR} macro.
+@RefMacro{BOOST_CONTRACT_DESTRUCTOR} macro.
 
 @Params
 @Param{class_type,
@@ -165,10 +167,11 @@
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
 // class_type: `vect<T>`, `(vect<T, A>)`, or `comma(1)(vect<T, A>)`.
-#define CONTRACT_DESTRUCTOR_BODY(class_type, destructor_name) \
- CONTRACT_BODY_CTOR_DTOR_(CONTRACT_AUX_BODY_DESTRUCTOR_CONTRACTED \
+#define BOOST_CONTRACT_DESTRUCTOR_BODY(class_type, destructor_name) \
+ BOOST_CONTRACT_BODY_CTOR_DTOR_( \
+ BOOST_CONTRACT_AUX_BODY_DESTRUCTOR_BOOST_CONTRACTED \
         , class_type, destructor_name \
- , CONTRACT_AUX_CONFIG_CLASS_INVARIANTS_01 \
+ , BOOST_CONTRACT_AUX_CONFIG_CLASS_INVARIANTS_01 \
     )
 
 #endif // #include guard

Modified: sandbox/contract/boost/contract/broken.hpp
==============================================================================
--- sandbox/contract/boost/contract/broken.hpp (original)
+++ sandbox/contract/boost/contract/broken.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,15 +5,15 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_BROKEN_HPP_
-#define CONTRACT_BROKEN_HPP_
+#ifndef BOOST_CONTRACT_BROKEN_HPP_
+#define BOOST_CONTRACT_BROKEN_HPP_
 
 /** @file
 @brief Contract broken handlers (this header is automatically included by
 <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/thread_variable.hpp>
+#include <boost/contract/aux_/thread_variable.hpp>
 #include <stdexcept>
 #include <sstream>
 #include <string>
@@ -25,7 +25,7 @@
 // NOTE: The contract broken handlers are similar to std::temrinate (inlining
 // functions also to avoid multiple definitions error).
 
-namespace contract {
+namespace boost { namespace contract {
 
 /**
 @brief Exception automatically thrown by the library to signal a contract
@@ -589,7 +589,7 @@
     // In general this could throw for user defined handlers.
     { aux::broken_handlers<>::loop_variant(context); }
 
-} // namespace
+} } // namespace
 
 #endif // #include guard
 

Modified: sandbox/contract/boost/contract/class.hpp
==============================================================================
--- sandbox/contract/boost/contract/class.hpp (original)
+++ sandbox/contract/boost/contract/class.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,16 +5,16 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_CLASS_HPP_
-#define CONTRACT_CLASS_HPP_
+#ifndef BOOST_CONTRACT_CLASS_HPP_
+#define BOOST_CONTRACT_CLASS_HPP_
 
 /** @file
 @brief Macros used to declare classes with contracts (this header is
 automatically included by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/macro/class.hpp>
-#include <contract/detail/preprocessor/traits/class.hpp>
+#include <boost/contract/aux_/macro/class.hpp>
+#include <boost/contract/detail/preprocessor/traits/class.hpp>
 
 /**
 @brief Macro used to declare classes with contracts.
@@ -22,11 +22,12 @@
 This macro is used to declare a class with class invariants and member
 functions with preconditions and postconditions.
 A class declared with this macro must always specify (possibly empty) class
-invariants using the @RefMacro{CONTRACT_CLASS_INVARIANT} macro.
+invariants using the @RefMacro{BOOST_CONTRACT_CLASS_INVARIANT} macro.
 
 Constructors, destructors, and member functions with contracts are declared
-using the @RefMacro{CONTRACT_CONSTRUCTOR}, @RefMacro{CONTRACT_DESTRUCTOR}, and
-_at_RefMacro{CONTRACT_FUNCTION} macros respectively.
+using the @RefMacro{BOOST_CONTRACT_CONSTRUCTOR},
+@RefMacro{BOOST_CONTRACT_DESTRUCTOR}, and @RefMacro{BOOST_CONTRACT_FUNCTION}
+macros respectively.
 The semantics of calls to constructors, destructors, and member functions with
 contracts are explained in the
 @RefSect{contract_programming_overview, Contract Programming Overview} section.
@@ -43,30 +44,30 @@
 always repeat their access level <c>public</c>, <c>protected</c>, or
 <c>private</c>.
 Within a type-dependent scope, nested classes with contracts must be declared
-using the @RefMacro{CONTRACT_CLASS_TPL} macro.
+using the @RefMacro{BOOST_CONTRACT_CLASS_TPL} macro.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_CLASS(class_declaration) \
- CONTRACT_AUX_CLASS( \
+#define BOOST_CONTRACT_CLASS(class_declaration) \
+ BOOST_CONTRACT_AUX_CLASS( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0, /* outside template */ \
- CONTRACT_DETAIL_PP_CLASS_TRAITS(class_declaration))
+ BOOST_CONTRACT_DETAIL_PP_CLASS_TRAITS(class_declaration))
 
 /**
 @brief Macro used to declare nested classes with contracts within a
 type-dependent scope (e.g., within templates).
 
-This macro is the exact same as @RefMacro{CONTRACT_CLASS} but it must be used
-when declaring nested classes with contracts within a type-dependent scope.
+This macro is the exact same as @RefMacro{BOOST_CONTRACT_CLASS} but it must be
+used when declaring nested classes with contracts within a type-dependent scope.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_CLASS_TPL(class_declaration) \
- CONTRACT_AUX_CLASS( \
+#define BOOST_CONTRACT_CLASS_TPL(class_declaration) \
+ BOOST_CONTRACT_AUX_CLASS( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1, /* inside template */ \
- CONTRACT_DETAIL_PP_CLASS_TRAITS(class_declaration))
+ BOOST_CONTRACT_DETAIL_PP_CLASS_TRAITS(class_declaration))
 
 #endif // #include guard
 

Modified: sandbox/contract/boost/contract/class_invariant.hpp
==============================================================================
--- sandbox/contract/boost/contract/class_invariant.hpp (original)
+++ sandbox/contract/boost/contract/class_invariant.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,16 +5,16 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_CLASS_INVARIANT_HPP_
-#define CONTRACT_CLASS_INVARIANT_HPP_
+#ifndef BOOST_CONTRACT_CLASS_INVARIANT_HPP_
+#define BOOST_CONTRACT_CLASS_INVARIANT_HPP_
 
 /** @file
 @brief Macros used to specify class invariants (this header is automatically
 included by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/macro/class_invariant.hpp>
-#include <contract/detail/preprocessor/variadic/to_seq.hpp>
+#include <boost/contract/aux_/macro/class_invariant.hpp>
+#include <boost/contract/detail/preprocessor/variadic/to_seq.hpp>
 #include <boost/local_function/detail/preprocessor/line_counter.hpp>
 #include <boost/config.hpp>
 
@@ -22,30 +22,30 @@
 
 #ifndef BOOST_NO_VARIADIC_MACROS
 
-#define CONTRACT_CLASS_INVARIANT(...) \
- CONTRACT_AUX_CLASS_INVARIANT( \
+#define BOOST_CONTRACT_CLASS_INVARIANT(...) \
+ BOOST_CONTRACT_AUX_CLASS_INVARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0 /* outside template */, \
- CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ((void) /* empty */, \
+ BOOST_CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ((void) /* empty */, \
                     __VA_ARGS__))
 
-#define CONTRACT_CLASS_INVARIANT_TPL(...) \
- CONTRACT_AUX_CLASS_INVARIANT( \
+#define BOOST_CONTRACT_CLASS_INVARIANT_TPL(...) \
+ BOOST_CONTRACT_AUX_CLASS_INVARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1 /* inside template */, \
- CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ((void) /* empty */, \
+ BOOST_CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ((void) /* empty */, \
                     __VA_ARGS__))
 
 #else
 
-#define CONTRACT_CLASS_INVARIANT(seq) \
- CONTRACT_AUX_CLASS_INVARIANT( \
+#define BOOST_CONTRACT_CLASS_INVARIANT(seq) \
+ BOOST_CONTRACT_AUX_CLASS_INVARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0, /* outside template */ \
             seq)
 
-#define CONTRACT_CLASS_INVARIANT_TPL(seq) \
- CONTRACT_AUX_CLASS_INVARIANT( \
+#define BOOST_CONTRACT_CLASS_INVARIANT_TPL(seq) \
+ BOOST_CONTRACT_AUX_CLASS_INVARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1, /* inside template */ \
             seq)
@@ -59,13 +59,14 @@
 
 This macro must be used to specify class invariant at the very beginning of the
 definition of a class with contracts declared using the
-_at_RefMacro{CONTRACT_CLASS} macro (no other statement can appear before this
+@RefMacro{BOOST_CONTRACT_CLASS} macro (no other statement can appear before this
 macro in the class definition, not even a <c>typedef</c> or a <c>friend</c>
 declaration).
 
 Constructors, destructors, and member functions with contracts are declared
-using the @RefMacro{CONTRACT_CONSTRUCTOR}, @RefMacro{CONTRACT_DESTRUCTOR}, and
-_at_RefMacro{CONTRACT_FUNCTION} macros respectively.
+using the @RefMacro{BOOST_CONTRACT_CONSTRUCTOR},
+@RefMacro{BOOST_CONTRACT_DESTRUCTOR}, and @RefMacro{BOOST_CONTRACT_FUNCTION}
+macros respectively.
 The semantics of calls to constructors, destructors, and member functions of a
 class with contracts are explained in the
 @RefSect{contract_programming_overview, Contract Programming Overview} section.
@@ -79,23 +80,23 @@
 @EndParams
 
 Within a type-dependent scope (e.g., within templates), the
-_at_RefMacro{CONTRACT_CLASS_INVARIANT_TPL} macro must be used instead of this
-macro.
+@RefMacro{BOOST_CONTRACT_CLASS_INVARIANT_TPL} macro must be used instead of
+this macro.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_CLASS_INVARIANT(class_invariants)
+#define BOOST_CONTRACT_CLASS_INVARIANT(class_invariants)
 
 /**
 @brief Macro used to specify class invariants within a type-dependent scope
 (e.g., within templates).
 
-This macro is the exact same as @RefMacro{CONTRACT_CLASS_INVARIANT} but it must
-be used when specifying class invariants within a type-dependent scope.
+This macro is the exact same as @RefMacro{BOOST_CONTRACT_CLASS_INVARIANT} but
+it must be used when specifying class invariants within a type-dependent scope.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_CLASS_INVARIANT_TPL(class_invariants)
+#define BOOST_CONTRACT_CLASS_INVARIANT_TPL(class_invariants)
 
 #endif
 

Modified: sandbox/contract/boost/contract/config.hpp
==============================================================================
--- sandbox/contract/boost/contract/constructor.hpp (original)
+++ sandbox/contract/boost/contract/constructor.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,17 +5,17 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_CONSTRUCTOR_HPP_
-#define CONTRACT_CONSTRUCTOR_HPP_
+#ifndef BOOST_CONTRACT_CONSTRUCTOR_HPP_
+#define BOOST_CONTRACT_CONSTRUCTOR_HPP_
 
 /** @file
 @brief Macros used to declare constructors with contracts (this header is
 automatically included by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/macro/function.hpp>
-#include <contract/aux_/preprocessor/func_kind.hpp>
-#include <contract/detail/preprocessor/traits/func.hpp>
+#include <boost/contract/aux_/macro/function.hpp>
+#include <boost/contract/aux_/preprocessor/func_kind.hpp>
+#include <boost/contract/detail/preprocessor/traits/func.hpp>
 
 /**
 @brief Macro used to declare constructors with contracts.
@@ -29,8 +29,8 @@
 The semantics of a call to a constructor with contracts are explained in the
 @RefSect{contract_programming_overview, Contract Programming Overview} section.
 Destructors and member functions are declared using the
-_at_RefMacro{CONTRACT_DESTRUCTOR} and @RefMacro{CONTRACT_FUNCTION} macros
-respectively.
+@RefMacro{BOOST_CONTRACT_DESTRUCTOR} and @RefMacro{BOOST_CONTRACT_FUNCTION}
+macros respectively.
 
 @Params
 @Param{function_declaration,
@@ -44,42 +44,44 @@
 }
 @EndParams
 
-The @RefMacro{CONTRACT_CLASS} macro must be used to declare the class enclosing
-a constructor declared using this macro.
+The @RefMacro{BOOST_CONTRACT_CLASS} macro must be used to declare the class
+enclosing a constructor declared using this macro.
 
 Within a type-dependent scope (e.g., within templates), the
-_at_RefMacro{CONTRACT_CONSTRUCTOR_TPL} macro must be used instead of this macro.
+@RefMacro{BOOST_CONTRACT_CONSTRUCTOR_TPL} macro must be used instead of this
+macro.
 
-The @RefMacro{CONTRACT_CONSTRUCTOR_BODY} macro must be used when separating the
-constructor body definition form the constructor declaration programmed using
-this macro.
+The @RefMacro{BOOST_CONTRACT_CONSTRUCTOR_BODY} macro must be used when
+separating the constructor body definition form the constructor declaration
+programmed using this macro.
 Unfortunately, it is not possible to use this macro so separate body
 definitions for constructors that have member initializers.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_CONSTRUCTOR(function_declaration) \
- CONTRACT_AUX_FUNCTION( \
+#define BOOST_CONTRACT_CONSTRUCTOR(function_declaration) \
+ BOOST_CONTRACT_AUX_FUNCTION( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0, /* outside template */ \
- CONTRACT_AUX_PP_FUNC_KIND_CONSTRUCTOR, \
- CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
+ BOOST_CONTRACT_AUX_PP_FUNC_KIND_CONSTRUCTOR, \
+ BOOST_CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
 
 /**
 @brief Macro used to declare constructors with contracts within a
 type-dependent scope (e.g., within templates).
 
-This macro is the exact same as @RefMacro{CONTRACT_CONSTRUCTOR} but it must be
-used when declaring constructors with contracts within a type-dependent scope.
+This macro is the exact same as @RefMacro{BOOST_CONTRACT_CONSTRUCTOR} but it
+must be used when declaring constructors with contracts within a type-dependent
+scope.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_CONSTRUCTOR_TPL(function_declaration) \
- CONTRACT_AUX_FUNCTION( \
+#define BOOST_CONTRACT_CONSTRUCTOR_TPL(function_declaration) \
+ BOOST_CONTRACT_AUX_FUNCTION( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1, /* inside template */ \
- CONTRACT_AUX_PP_FUNC_KIND_CONSTRUCTOR, \
- CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
+ BOOST_CONTRACT_AUX_PP_FUNC_KIND_CONSTRUCTOR, \
+ BOOST_CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
 
 #endif // #include guard
 

Modified: sandbox/contract/boost/contract/copy.hpp
==============================================================================
--- sandbox/contract/boost/contract/copy.hpp (original)
+++ sandbox/contract/boost/contract/copy.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,8 +5,8 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_COPY_HPP_
-#define CONTRACT_COPY_HPP_
+#ifndef BOOST_CONTRACT_COPY_HPP_
+#define BOOST_CONTRACT_COPY_HPP_
 
 /** @file
 @brief Copy result value and old values for postconditions (this header is
@@ -17,7 +17,7 @@
 #include <boost/type_traits/add_reference.hpp>
 #include <boost/noncopyable.hpp>
 
-namespace contract {
+namespace boost { namespace contract {
 
 /**
 @brief Copy result value and old values for postconditions.
@@ -71,7 +71,7 @@
     typename boost::add_const<T>::type value_;
 };
 
-} // namespace contract
+} } // namespace
 
 #endif // #include guard
 

Modified: sandbox/contract/boost/contract/destructor.hpp
==============================================================================
--- sandbox/contract/boost/contract/destructor.hpp (original)
+++ sandbox/contract/boost/contract/destructor.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,17 +5,17 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_DESTRUCTOR_HPP_
-#define CONTRACT_DESTRUCTOR_HPP_
+#ifndef BOOST_CONTRACT_DESTRUCTOR_HPP_
+#define BOOST_CONTRACT_DESTRUCTOR_HPP_
 
 /** @file
 @brief Macros used to declare destructors with contracts (this header is
 automatically included by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/macro/function.hpp>
-#include <contract/aux_/preprocessor/func_kind.hpp>
-#include <contract/detail/preprocessor/traits/func.hpp>
+#include <boost/contract/aux_/macro/function.hpp>
+#include <boost/contract/aux_/preprocessor/func_kind.hpp>
+#include <boost/contract/detail/preprocessor/traits/func.hpp>
 
 /**
 @brief Macro used to declare destructors with contracts.
@@ -28,8 +28,8 @@
 The semantics of a call to a destructor with contracts are explained in the
 @RefSect{contract_programming_overview, Contract Programming Overview} section.
 Constructor and member functions are declared using the
-_at_RefMacro{CONTRACT_CONSTRUCTOR} and @RefMacro{CONTRACT_FUNCTION} macros
-respectively.
+@RefMacro{BOOST_CONTRACT_CONSTRUCTOR} and @RefMacro{BOOST_CONTRACT_FUNCTION}
+macros respectively.
 
 @Params
 @Param{function_declaration,
@@ -42,40 +42,42 @@
 }
 @EndParams
 
-The @RefMacro{CONTRACT_CLASS} macro must be used to declare the class enclosing
-a destructor declared using this macro.
+The @RefMacro{BOOST_CONTRACT_CLASS} macro must be used to declare the class
+enclosing a destructor declared using this macro.
 
 Within a type-dependent scope (e.g., within templates), the
-_at_RefMacro{CONTRACT_DESTRUCTOR_TPL} macro must be used instead of this macro.
+@RefMacro{BOOST_CONTRACT_DESTRUCTOR_TPL} macro must be used instead of this
+macro.
 
-The @RefMacro{CONTRACT_DESTRUCTOR_BODY} macro must be used when separating the
-destructor body definition from the destruction declaration programmed using
-this macro.
+The @RefMacro{BOOST_CONTRACT_DESTRUCTOR_BODY} macro must be used when
+separating the destructor body definition from the destruction declaration
+programmed using this macro.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_DESTRUCTOR(function_declaration) \
- CONTRACT_AUX_FUNCTION( \
+#define BOOST_CONTRACT_DESTRUCTOR(function_declaration) \
+ BOOST_CONTRACT_AUX_FUNCTION( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0, /* outside template */ \
- CONTRACT_AUX_PP_FUNC_KIND_DESTRUCTOR, \
- CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
+ BOOST_CONTRACT_AUX_PP_FUNC_KIND_DESTRUCTOR, \
+ BOOST_CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
 
 /**
 @brief Macro used to declare destructors with contracts within a type-dependent
 scope (e.g., within templates).
 
-This macro is the exact same as @RefMacro{CONTRACT_DESTRUCTOR} but it must be
-used when declaring destructors with contracts within a type-dependent scope.
+This macro is the exact same as @RefMacro{BOOST_CONTRACT_DESTRUCTOR} but it
+must be used when declaring destructors with contracts within a type-dependent
+scope.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_DESTRUCTOR_TPL(function_declaration) \
- CONTRACT_AUX_FUNCTION( \
+#define BOOST_CONTRACT_DESTRUCTOR_TPL(function_declaration) \
+ BOOST_CONTRACT_AUX_FUNCTION( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1, /* inside template */ \
- CONTRACT_AUX_PP_FUNC_KIND_DESTRUCTOR, \
- CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
+ BOOST_CONTRACT_AUX_PP_FUNC_KIND_DESTRUCTOR, \
+ BOOST_CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
 
 #endif // #include guard
 

Modified: sandbox/contract/boost/contract/function.hpp
==============================================================================
--- sandbox/contract/boost/contract/function.hpp (original)
+++ sandbox/contract/boost/contract/function.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,17 +5,17 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_FUNCTION_HPP_
-#define CONTRACT_FUNCTION_HPP_
+#ifndef BOOST_CONTRACT_FUNCTION_HPP_
+#define BOOST_CONTRACT_FUNCTION_HPP_
 
 /** @file
 @brief Macros used to declare free functions, member functions, and operators
 with contracts (this header is automatically included by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/macro/function.hpp>
-#include <contract/aux_/preprocessor/func_kind.hpp>
-#include <contract/detail/preprocessor/traits/func.hpp>
+#include <boost/contract/aux_/macro/function.hpp>
+#include <boost/contract/aux_/preprocessor/func_kind.hpp>
+#include <boost/contract/detail/preprocessor/traits/func.hpp>
 #include <boost/local_function/detail/preprocessor/line_counter.hpp>
 
 /**
@@ -32,8 +32,8 @@
 The semantics of a call to a function with contracts are explained in the
 @RefSect{contract_programming_overview, Contract Programming Overview} section.
 Constructors and destructors are declared using the
-_at_RefMacro{CONTRACT_CONSTRUCTOR} and @RefMacro{CONTRACT_DESTRUCTOR} macros
-respectively.
+@RefMacro{BOOST_CONTRACT_CONSTRUCTOR} and @RefMacro{BOOST_CONTRACT_DESTRUCTOR}
+macros respectively.
 
 @Params
 @Param{function_declaration,
@@ -45,41 +45,43 @@
 }
 @EndParams
 
-The @RefMacro{CONTRACT_CLASS} macro must be used to declare classes enclosing
-member functions and member function operators declared using this macro.
+The @RefMacro{BOOST_CONTRACT_CLASS} macro must be used to declare classes
+enclosing member functions and member function operators declared using this
+macro.
 
 Within a type-dependent scope (e.g., within templates), the
-_at_RefMacro{CONTRACT_FUNCTION_TPL} macro must be used instead of this macro.
+@RefMacro{BOOST_CONTRACT_FUNCTION_TPL} macro must be used instead of this macro.
 
-The @RefMacro{CONTRACT_FREE_BODY} and @RefMacro{CONTRACT_MEMBER_BODY} macros
-must be used when separating free and member function body definitions from the
-function declarations programmed using this macro.
+The @RefMacro{BOOST_CONTRACT_FREE_BODY} and
+@RefMacro{BOOST_CONTRACT_MEMBER_BODY} macros must be used when separating free
+and member function body definitions from the function declarations programmed
+using this macro.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_FUNCTION(function_declaration) \
- CONTRACT_AUX_FUNCTION( \
+#define BOOST_CONTRACT_FUNCTION(function_declaration) \
+ BOOST_CONTRACT_AUX_FUNCTION( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0, /* outside template */ \
- CONTRACT_AUX_PP_FUNC_KIND_FUNCTION, \
- CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
+ BOOST_CONTRACT_AUX_PP_FUNC_KIND_FUNCTION, \
+ BOOST_CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
 
 /**
 @brief Macro used to declared free functions, free function operators, member
 functions, and member function operators with contracts within a type-dependent
 scope (e.g., within templates).
 
-This macro is the exact same as @RefMacro{CONTRACT_FUNCTION} but it must be
-used when declaring functions with contracts within a type-dependent scope.
+This macro is the exact same as @RefMacro{BOOST_CONTRACT_FUNCTION} but it must
+be used when declaring functions with contracts within a type-dependent scope.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#define CONTRACT_FUNCTION_TPL(function_declaration) \
- CONTRACT_AUX_FUNCTION( \
+#define BOOST_CONTRACT_FUNCTION_TPL(function_declaration) \
+ BOOST_CONTRACT_AUX_FUNCTION( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1, /* inside template */ \
- CONTRACT_AUX_PP_FUNC_KIND_FUNCTION, \
- CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
+ BOOST_CONTRACT_AUX_PP_FUNC_KIND_FUNCTION, \
+ BOOST_CONTRACT_DETAIL_PP_FUNC_TRAITS(function_declaration))
 
 #endif // #include guard
 

Modified: sandbox/contract/boost/contract/limits.hpp
==============================================================================
--- sandbox/contract/boost/contract/limits.hpp (original)
+++ sandbox/contract/boost/contract/limits.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,8 +5,8 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_LIMITS_HPP_
-#define CONTRACT_LIMITS_HPP_
+#ifndef BOOST_CONTRACT_LIMITS_HPP_
+#define BOOST_CONTRACT_LIMITS_HPP_
 
 /** @file
 @brief Macros reporting bounds of some library constructs (this header is
@@ -22,7 +22,8 @@
 @brief Upper bound on possible maximum number of postcondition old variables.
 
 The maximum possible number of postcondition old variables is <c>15</c> (the
-actual maximum value is controlled by @RefMacro{CONTRACT_CONFIG_OLDOF_MAX}).
+actual maximum value is controlled by
+@RefMacro{BOOST_CONTRACT_CONFIG_OLDOF_MAX}).
 
 For compilers that do not support variadic macros, this is the maximum possible
 total number of postcondition statements (total of old variable declarations,
@@ -34,7 +35,7 @@
 @SeeAlso @RefSect{tutorial, Tutorial} section,
 @RefSect{no_variadic_macros, No Variadic Macros} section.
 */
-#define CONTRACT_LIMIT_OLDOFS 15
+#define BOOST_CONTRACT_LIMIT_OLDOFS 15
 
 /**
 @brief Maximum number of select assertions that can be nested into one another.
@@ -47,7 +48,7 @@
 
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
-#define CONTRACT_LIMIT_NESTED_SELECT_ASSERTIONS 5
+#define BOOST_CONTRACT_LIMIT_NESTED_SELECT_ASSERTIONS 5
 
 /**
 @brief Maximum number of catch statements for a constructor-try block with
@@ -56,15 +57,15 @@
 The maximum number of catch statements for a constructor-try block with member
 initializers is <c>10</c>.
 (Constructor-try blocks are specified outside the
-_at_RefMacro{CONTRACT_CONSTRUCTOR} macro when the is no member initializers so
-this limit does not apply to that case.)
+@RefMacro{BOOST_CONTRACT_CONSTRUCTOR} macro when the is no member initializers
+so this limit does not apply to that case.)
 
 @Note This is not a configuration macro.
 The value of this macro is fixed and programmers cannot change it.
 
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
-#define CONTRACT_LIMIT_CONSTRUCTOR_TRY_BLOCK_CATCHES 10
+#define BOOST_CONTRACT_LIMIT_CONSTRUCTOR_TRY_BLOCK_CATCHES 10
 
 #endif // #include guard
 

Modified: sandbox/contract/boost/contract/loop_variant.hpp
==============================================================================
--- sandbox/contract/boost/contract/loop_variant.hpp (original)
+++ sandbox/contract/boost/contract/loop_variant.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,17 +5,17 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_LOOP_VARIANT_HPP_
-#define CONTRACT_LOOP_VARIANT_HPP_
+#ifndef BOOST_CONTRACT_LOOP_VARIANT_HPP_
+#define BOOST_CONTRACT_LOOP_VARIANT_HPP_
 
 /** @file
 @brief Macros used to specify loop variants (this header is automatically
 included by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/loop_variant.hpp>
-#include <contract/aux_/macro/loop_variant.hpp>
-#include <contract/detail/preprocessor/variadic/to_seq.hpp>
+#include <boost/contract/aux_/loop_variant.hpp>
+#include <boost/contract/aux_/macro/loop_variant.hpp>
+#include <boost/contract/detail/preprocessor/variadic/to_seq.hpp>
 #include <boost/local_function/detail/preprocessor/line_counter.hpp>
 #include <boost/config.hpp>
 
@@ -25,7 +25,7 @@
 @brief Macro used to declare a loop that will specify a loop variant.
 
 This macro must be used to declare a loop that will later specify a loop
-variant using the @RefMacro{CONTRACT_LOOP_VARIANT} macro.
+variant using the @RefMacro{BOOST_CONTRACT_LOOP_VARIANT} macro.
 
 @Params
 @Param{loop_declaration,
@@ -37,7 +37,7 @@
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
 // No need for LOOP_TPL because variant decl always int and never type-depend.
-#define CONTRACT_LOOP(loop_declaration) \
+#define BOOST_CONTRACT_LOOP(loop_declaration) \
     /* NOTE: this declared trick (originally from Boost.ScopeExit) allows */ \
     /* redefine the old variant with the same name in the same scope */ \
     /* without the "duplicate definition" compiler-error (this avoids the */ \
@@ -45,13 +45,13 @@
     /* avoiding an additional LOOP_END macro) plus it prevents the compiler */ \
     /* warning "unused variable" in case the loop variant expression is */ \
     /* disabled by importance ordering */ \
- BOOST_PP_EXPR_IIF(CONTRACT_AUX_CONFIG_LOOP_VARIANTS_01, \
+ BOOST_PP_EXPR_IIF(BOOST_CONTRACT_AUX_CONFIG_LOOP_VARIANTS_01, \
         ::contract::aux::loop_variant::declared< \
             ::contract::aux::loop_variant::resolve< \
- sizeof(CONTRACT_AUX_CODE_LOOP_VARIANT_OLD_VAR) \
+ sizeof(BOOST_CONTRACT_AUX_CODE_LOOP_VARIANT_OLD_VAR) \
>::cmp1<0>::cmp2 \
- > CONTRACT_AUX_CODE_LOOP_VARIANT_OLD_VAR; \
- CONTRACT_AUX_CODE_LOOP_VARIANT_OLD_VAR.value = \
+ > BOOST_CONTRACT_AUX_CODE_LOOP_VARIANT_OLD_VAR; \
+ BOOST_CONTRACT_AUX_CODE_LOOP_VARIANT_OLD_VAR.value = \
                 ::contract::aux::loop_variant::uninitialized; \
     ) \
     loop_declaration
@@ -60,30 +60,30 @@
 
 #ifndef BOOST_NO_VARIADIC_MACROS
 
-#define CONTRACT_LOOP_VARIANT(...) \
- CONTRACT_AUX_LOOP_VARIANT( \
+#define BOOST_CONTRACT_LOOP_VARIANT(...) \
+ BOOST_CONTRACT_AUX_LOOP_VARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0 /* outside template */, \
- CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ( \
+ BOOST_CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ( \
                     ERROR_loop_variant_cannot_be_empty, __VA_ARGS__))
 
-#define CONTRACT_LOOP_VARIANT_TPL(...) \
- CONTRACT_AUX_LOOP_VARIANT( \
+#define BOOST_CONTRACT_LOOP_VARIANT_TPL(...) \
+ BOOST_CONTRACT_AUX_LOOP_VARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1 /* inside template */, \
- CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ( \
+ BOOST_CONTRACT_DETAIL_PP_VARIADIC_TO_SEQ( \
                     ERROR_loop_variant_cannot_be_empty, __VA_ARGS__))
 
 #else
 
-#define CONTRACT_LOOP_VARIANT(seq) \
- CONTRACT_AUX_LOOP_VARIANT( \
+#define BOOST_CONTRACT_LOOP_VARIANT(seq) \
+ BOOST_CONTRACT_AUX_LOOP_VARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             0, /* outside template */ \
             seq)
 
-#define CONTRACT_LOOP_VARIANT_TPL(seq) \
- CONTRACT_AUX_LOOP_VARIANT( \
+#define BOOST_CONTRACT_LOOP_VARIANT_TPL(seq) \
+ BOOST_CONTRACT_AUX_LOOP_VARIANT( \
             BOOST_LOCAL_FUNCTION_DETAIL_PP_LINE_COUNTER, \
             1, /* inside template */ \
             seq)
@@ -97,7 +97,7 @@
 
 This macro is used to specify loop variants which ensure that loops terminate.
 This macro must be used within the body <c>{ ... }</c> of a loop declared using
-the @RefMacro{CONTRACT_LOOP} macro.
+the @RefMacro{BOOST_CONTRACT_LOOP} macro.
 Each loop can have at most one loop variant.
 
 @Params
@@ -110,22 +110,23 @@
 @EndParams
 
 Within type-dependent scope (e.g., within templates), the
-_at_RefMacro{CONTRACT_LOOP_VARIANT_TPL} macro must be used instead of this macro.
+@RefMacro{BOOST_CONTRACT_LOOP_VARIANT_TPL} macro must be used instead of this
+macro.
 
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
-#define CONTRACT_LOOP_VARIANT(loop_variant)
+#define BOOST_CONTRACT_LOOP_VARIANT(loop_variant)
 
 /**
 @brief Macro used to specify a loop variant within a type-dependent scope
 (e.g., within templates).
 
-This macro is the exact same as @RefMacro{CONTRACT_LOOP_VARIANT} but it must be
-used when specifying loop variants within a type-dependent scope.
+This macro is the exact same as @RefMacro{BOOST_CONTRACT_LOOP_VARIANT} but it
+must be used when specifying loop variants within a type-dependent scope.
 
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
-#define CONTRACT_LOOP_VARIANT_TPL(loop_variant)
+#define BOOST_CONTRACT_LOOP_VARIANT_TPL(loop_variant)
 
 #endif
 

Modified: sandbox/contract/boost/contract/oldof.hpp
==============================================================================
--- sandbox/contract/boost/contract/oldof.hpp (original)
+++ sandbox/contract/boost/contract/oldof.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,8 +5,8 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_OLDOF_HPP_
-#define CONTRACT_OLDOF_HPP_
+#ifndef BOOST_CONTRACT_OLDOF_HPP_
+#define BOOST_CONTRACT_OLDOF_HPP_
 
 /** @file
 @brief Constructs to declare postcondition old values (this header is
@@ -25,7 +25,7 @@
 postconditions (see also the @RefSect{grammar, Grammar} section):
 
 @code
-auto old_variable = CONTRACT_OLDOF odlof_expression
+auto old_variable = BOOST_CONTRACT_OLDOF odlof_expression
 @endcode
 
 The specified expression that follows the macro might or not be wrapped within parenthesis.
@@ -43,9 +43,10 @@
 */
 // Used to mark start of oldof expression within an oldof assignment
 // (unbalanced parenthesis `) ... (` will balance within user code).
-#define CONTRACT_OLDOF ) postcondition(CONTRACT_DETAIL_PP_TRAITS_OLDOF
+#define BOOST_CONTRACT_OLDOF \
+ ) postcondition(BOOST_CONTRACT_DETAIL_PP_TRAITS_OLDOF
 
-namespace contract {
+namespace boost { namespace contract {
 
 /**
 @brief Trait used to determine if a type can be copied for an old value or not.
@@ -66,7 +67,7 @@
 
 @Params
 @Param{OldofExpressionType,
-The type of the expression specified to the @RefMacro{CONTRACT_OLDOF} macro for
+The type of the expression specified to the @RefMacro{BOOST_CONTRACT_OLDOF} macro for
 a given postcondition old value declaration.
 }
 @EndParams
@@ -85,7 +86,7 @@
 template< typename OldofExpressionType >
 struct has_oldof : boost::mpl::true_ {};
 
-} // namespace contract
+} } // namespace
 
 #endif // #include guard
 

Modified: sandbox/contract/boost/contract/parameter.hpp
==============================================================================
--- sandbox/contract/boost/contract/parameter.hpp (original)
+++ sandbox/contract/boost/contract/parameter.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,53 +5,58 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_PARAMETER_HPP_
-#define CONTRACT_PARAMETER_HPP_
+#ifndef BOOST_CONTRACT_PARAMETER_HPP_
+#define BOOST_CONTRACT_PARAMETER_HPP_
 
 /** @file
 @brief Macros used to program named and deduced parameters (this header is
 automatically included by <c>contract.hpp</c>).
 */
 
-#include <contract/aux_/named_params.hpp>
-#include <contract/aux_/macro/parameter.hpp>
-#include <contract/aux_/macro/body.hpp>
-#include <contract/aux_/macro/code_/named_params_/constructor.hpp>
-#include <contract/detail/preprocessor/keyword/namespace.hpp>
+#include <boost/contract/aux_/named_params.hpp>
+#include <boost/contract/aux_/macro/parameter.hpp>
+#include <boost/contract/aux_/macro/body.hpp>
+#include <boost/contract/aux_/macro/code_/named_params_/constructor.hpp>
+#include <boost/contract/detail/preprocessor/keyword/namespace.hpp>
 
 // PRIVATE //
 
 #ifndef DOXYGEN
 
-#define CONTRACT_PARAMETER_TRAITS_NAMESPACE_SPLIT_namespace(tag_namespace) \
+#define BOOST_CONTRACT_PARAMETER_TRAITS_NAMESPACE_SPLIT_namespace( \
+ tag_namespace) \
     tag_namespace,
 
-#define CONTRACT_PARAMETER_TRAITS_NAMESPACE_YES_(sign) \
- ( CONTRACT_PARAMETER_TRAITS_NAMESPACE_SPLIT_ ## sign )
+#define BOOST_CONTRACT_PARAMETER_TRAITS_NAMESPACE_YES_(sign) \
+ ( BOOST_CONTRACT_PARAMETER_TRAITS_NAMESPACE_SPLIT_ ## sign )
 
-#define CONTRACT_PARAMETER_TRAITS_NAMESPACE_(sign) \
- BOOST_PP_IIF(CONTRACT_DETAIL_PP_KEYWORD_IS_NAMESPACE_FRONT(sign), \
- CONTRACT_PARAMETER_TRAITS_NAMESPACE_YES_ \
+#define BOOST_CONTRACT_PARAMETER_TRAITS_NAMESPACE_(sign) \
+ BOOST_PP_IIF(BOOST_CONTRACT_DETAIL_PP_KEYWORD_IS_NAMESPACE_FRONT(sign), \
+ BOOST_CONTRACT_PARAMETER_TRAITS_NAMESPACE_YES_ \
     , \
- (CONTRACT_AUX_CONFIG_NAMED_PARAMETER_TAG_NAMESPACE_DEFAULT, sign) \
+ ( \
+ BOOST_CONTRACT_AUX_CONFIG_NAMED_PARAMETER_TAG_NAMESPACE_DEFAULT \
+ , \
+ sign \
+ ) \
         BOOST_PP_TUPLE_EAT(1) \
     )(sign)
      
-#define CONTRACT_PARAMETER_TRAITS_PASSING_SPLIT_(passing_name) \
+#define BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_SPLIT_(passing_name) \
     passing_name,
 
-#define CONTRACT_PARAMETER_TRAITS_PASSING_YES_(tag_namespace, sign) \
+#define BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_YES_(tag_namespace, sign) \
     ( \
         tag_namespace \
     , \
         BOOST_PP_TUPLE_ELEM(2, 0, \
- (CONTRACT_PARAMETER_TRAITS_PASSING_SPLIT_ sign) ) \
+ (BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_SPLIT_ sign) ) \
     , \
         BOOST_PP_TUPLE_ELEM(2, 1, \
- (CONTRACT_PARAMETER_TRAITS_PASSING_SPLIT_ sign) ) \
+ (BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_SPLIT_ sign) ) \
     )
 
-#define CONTRACT_PARAMETER_TRAITS_PASSING_NO_(tag_namespace, name) \
+#define BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_NO_(tag_namespace, name) \
     /* default passing name postfixed with `_` (postfix like for Boost */ \
     /* keyword identifiers, named parameters are also called keyword */ \
     /* parameters, plus if prefix like for placeholder then can generate */ \
@@ -59,19 +64,19 @@
     /* case, for example for template parameters _Valuetype) */ \
     (tag_namespace, BOOST_PP_CAT(name, _), name)
 
-#define CONTRACT_PARAMETER_TRAITS_PASSING_(namespace_sign) \
+#define BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_(namespace_sign) \
     BOOST_PP_IIF(BOOST_PP_IS_UNARY(BOOST_PP_TUPLE_ELEM(2, 1, namespace_sign)), \
- CONTRACT_PARAMETER_TRAITS_PASSING_YES_ \
+ BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_YES_ \
     , \
- CONTRACT_PARAMETER_TRAITS_PASSING_NO_ \
+ BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_NO_ \
     )( \
           BOOST_PP_TUPLE_ELEM(2, 0, namespace_sign) \
         , BOOST_PP_TUPLE_ELEM(2, 1, namespace_sign) \
     )
 
-#define CONTRACT_PARAMETER_TRAITS_(sign) \
- CONTRACT_PARAMETER_TRAITS_PASSING_( \
- CONTRACT_PARAMETER_TRAITS_NAMESPACE_( \
+#define BOOST_CONTRACT_PARAMETER_TRAITS_(sign) \
+ BOOST_CONTRACT_PARAMETER_TRAITS_PASSING_( \
+ BOOST_CONTRACT_PARAMETER_TRAITS_NAMESPACE_( \
         sign \
     ))
 
@@ -91,7 +96,7 @@
 @Params
 @Param{parameter_name,
 The name of a constructor named or deduced parameter previously declared using
-the @RefMacro{CONTRACT_PARAMETER} macro.
+the @RefMacro{BOOST_CONTRACT_PARAMETER} macro.
 }
 @EndParams
 
@@ -99,9 +104,9 @@
 */
 // To be used to access parameter values within constructor member initializers
 // and try-blocks (this limitation comes from lack of delegating constructors).
-#define CONTRACT_CONSTRUCTOR_ARG(parameter_name) \
+#define BOOST_CONTRACT_CONSTRUCTOR_ARG(parameter_name) \
     /* extra parenthesis () to make sure this expr is evaluated as whole */ \
- ( CONTRACT_AUX_CODE_NAMED_PARAMS_CONSTRUCTOR_ARG(parameter_name) )
+ ( BOOST_CONTRACT_AUX_CODE_NAMED_PARAMS_CONSTRUCTOR_ARG(parameter_name) )
 
 /**
 @brief Macro used to access the actual type of a named or deduced parameter.
@@ -115,7 +120,7 @@
 @Params
 @Param{parameter_name,
 The name of a named or deduced parameter previously declared using the
-_at_RefMacro{CONTRACT_PARAMETER} macro.
+@RefMacro{BOOST_CONTRACT_PARAMETER} macro.
 }
 @EndParams
 
@@ -127,15 +132,15 @@
 // Do not expose Boost.Parameter's internal conventions to use
 // tag::param_name::_ or param_name_type to access type plus uses the same
 // way to access param type in all requirement expressions, concepts, etc.
-#define CONTRACT_PARAMETER_TYPEOF(parameter_name) \
- CONTRACT_AUX_PARAMETER_BOOST_TYPE(parameter_name)
+#define BOOST_CONTRACT_PARAMETER_TYPEOF(parameter_name) \
+ BOOST_CONTRACT_AUX_PARAMETER_BOOST_TYPE(parameter_name)
 
 /**
 @brief Macro used to declare a named or deduced function parameter.
 
 This macro is used to declare a named or deduced parameter that will later be
-used within a function declared using the @RefMacro{CONTRACT_FUNCTION} or the
-_at_RefMacro{CONTRACT_CONSTRUCTOR} macros.
+used within a function declared using the @RefMacro{BOOST_CONTRACT_FUNCTION} or the
+@RefMacro{BOOST_CONTRACT_CONSTRUCTOR} macros.
 This macro should be used at namespace scope.
 
 @Params
@@ -153,15 +158,15 @@
 @SeeAlso @RefSect{named_parameters, Named Parameters} section.
 */
 // sign: [namespace(tag_namespace_)] [(passing_name_)] name_
-#define CONTRACT_PARAMETER(named_parameter_declaration) \
- BOOST_PP_EXPAND(CONTRACT_AUX_PARAMETER_BOOST_PARAM \
- CONTRACT_PARAMETER_TRAITS_(named_parameter_declaration))
+#define BOOST_CONTRACT_PARAMETER(named_parameter_declaration) \
+ BOOST_PP_EXPAND(BOOST_CONTRACT_AUX_PARAMETER_BOOST_PARAM \
+ BOOST_CONTRACT_PARAMETER_TRAITS_(named_parameter_declaration))
 
 /**
 @brief Macro used to declare a named or deduced template parameter.
 
 This macro is used to declare a named or deduced parameter that will later be
-used within a class template declared using the @RefMacro{CONTRACT_CLASS}
+used within a class template declared using the @RefMacro{BOOST_CONTRACT_CLASS}
 macro.
 This macro should be used at namespace scope.
 
@@ -180,9 +185,9 @@
 @SeeAlso @RefSect{named_parameters, Named Parameters} section.
 */
 // sign: [namespace(tag_namespace_)] [(passing_name_)] name_
-#define CONTRACT_TEMPLATE_PARAMETER(named_parameter_declaration) \
- BOOST_PP_EXPAND(CONTRACT_AUX_PARAMETER_BOOST_TEMPLATE_PARAM \
- CONTRACT_PARAMETER_TRAITS_(named_parameter_declaration))
+#define BOOST_CONTRACT_TEMPLATE_PARAMETER(named_parameter_declaration) \
+ BOOST_PP_EXPAND(BOOST_CONTRACT_AUX_PARAMETER_BOOST_TEMPLATE_PARAM \
+ BOOST_CONTRACT_PARAMETER_TRAITS_(named_parameter_declaration))
 
 /**
 @brief Macro used to name the body of free and member functions with named
@@ -200,7 +205,7 @@
 For member functions, the class type must precede this macro (this allows to
 use this same macro for both free and member functions):
 @code
-class_type::CONTRACT_PARAMETER_BODY(function_name)
+class_type::BOOST_CONTRACT_PARAMETER_BODY(function_name)
 @endcode
 
 @Note Named parameters are currently not supported for operators so this
@@ -215,10 +220,10 @@
 
 @SeeAlso @RefSect{named_parameters, Named Parameters} section.
 */
-#define CONTRACT_PARAMETER_BODY(function_name) \
+#define BOOST_CONTRACT_PARAMETER_BODY(function_name) \
     /* always "contracted" because named parameter functions always need to */ \
     /* use the extra body function regardless of contract enabled or not */ \
- CONTRACT_AUX_BODY_PARAMETER_FUNCTION_CONTRACTED(function_name)
+ BOOST_CONTRACT_AUX_BODY_PARAMETER_FUNCTION_BOOST_CONTRACTED(function_name)
 
 #endif // #include guard
 


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/contract/boost/contract/config.hpp (original)
+++ sandbox/contract/boost/contract/config.hpp 2013-02-28 20:00:22 EST (Thu, 28 Feb 2013)
@@ -5,8 +5,8 @@
 // http://www.boost.org/LICENSE_1_0.txt)
 // Home at http://sourceforge.net/projects/contractpp
 
-#ifndef CONTRACT_CONFIG_HPP_
-#define CONTRACT_CONFIG_HPP_
+#ifndef BOOST_CONTRACT_CONFIG_HPP_
+#define BOOST_CONTRACT_CONFIG_HPP_
 
 /** @file
 @brief Macros used to configure the library behaviour at compile-time (this
@@ -17,10 +17,10 @@
 (using compiler options like <c>-D</c> for GCC, <c>/D</c> for MSVC, etc) in
 order to change the library behaviour.
 
-The macros @RefMacro{CONTRACT_CONFIG_NO_PRECONDITIONS},
-_at_RefMacro{CONTRACT_CONFIG_NO_POSTCONDITIONS}, etc can be defined to selectively
-disable compilation and run-time checking of all preconditions, postconditions,
-etc.
+The macros @RefMacro{BOOST_CONTRACT_CONFIG_NO_PRECONDITIONS},
+@RefMacro{BOOST_CONTRACT_CONFIG_NO_POSTCONDITIONS}, etc can be defined to
+selectively disable compilation and run-time checking of all preconditions,
+postconditions, etc.
 This is a common practice in Contract Programming to generate debug and release
 builds with less correctness checks but faster run-times.
 Note that all contracts are compiled and checked at run-time by default unless
@@ -30,7 +30,7 @@
 @RefSect{contract_programming_overview, Contract Programming Overview} section.
 */
 
-#include <contract/limits.hpp>
+#include <boost/contract/limits.hpp>
 
 // All these macros are undefined by default (unless generating Doxygen docs).
 // Virtual specifiers (final, override, and new) are enabled iff contracts
@@ -51,7 +51,7 @@
 
 @SeeAlso @RefSect{getting_started, Getting Started} section.
 */
-#define CONTRACT_CONFIG_NO_PRECONDITIONS
+#define BOOST_CONTRACT_CONFIG_NO_PRECONDITIONS
 
 /**
 @brief Disable compilation and run-time checking of all postconditions.
@@ -67,7 +67,7 @@
 
 @SeeAlso @RefSect{getting_started, Getting Started} section.
 */
-#define CONTRACT_CONFIG_NO_POSTCONDITIONS
+#define BOOST_CONTRACT_CONFIG_NO_POSTCONDITIONS
 
 /**
 @brief Disable compilation and run-time checking of all class invariants.
@@ -83,7 +83,7 @@
 
 @SeeAlso @RefSect{getting_started, Getting Started} section.
 */
-#define CONTRACT_CONFIG_NO_CLASS_INVARIANTS
+#define BOOST_CONTRACT_CONFIG_NO_CLASS_INVARIANTS
 
 /**
 @brief Disable compilation and run-time checking of all block invariants.
@@ -99,7 +99,7 @@
 
 @SeeAlso @RefSect{getting_started, Getting Started} section.
 */
-#define CONTRACT_CONFIG_NO_BLOCK_INVARIANTS
+#define BOOST_CONTRACT_CONFIG_NO_BLOCK_INVARIANTS
 
 /**
 @brief Disable compilation and run-time checking of all loop variants.
@@ -115,7 +115,7 @@
 
 @SeeAlso @RefSect{getting_started, Getting Started} section.
 */
-#define CONTRACT_CONFIG_NO_LOOP_VARIANTS
+#define BOOST_CONTRACT_CONFIG_NO_LOOP_VARIANTS
 
 #endif // DOXYGEN
 
@@ -128,8 +128,8 @@
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#ifndef CONTRACT_CONFIG_FUNCTION_ARITY_MAX
-# define CONTRACT_CONFIG_FUNCTION_ARITY_MAX 5
+#ifndef BOOST_CONTRACT_CONFIG_FUNCTION_ARITY_MAX
+# define BOOST_CONTRACT_CONFIG_FUNCTION_ARITY_MAX 5
 #endif
 
 /**
@@ -142,8 +142,8 @@
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#ifndef CONTRACT_CONFIG_INHERITANCE_MAX
-# define CONTRACT_CONFIG_INHERITANCE_MAX 4
+#ifndef BOOST_CONTRACT_CONFIG_INHERITANCE_MAX
+# define BOOST_CONTRACT_CONFIG_INHERITANCE_MAX 4
 #endif
 
 /**
@@ -152,16 +152,16 @@
 
 This macro automatically defaults to <c>5</c> if left undefined by programmers.
 This macro must be a non-negative integral number smaller or equal to
-_at_RefMacro{CONTRACT_LIMIT_OLDOFS}.
+@RefMacro{BOOST_CONTRACT_LIMIT_OLDOFS}.
 Increasing the value specified by this macro might increase compilation time.
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#ifndef CONTRACT_CONFIG_OLDOF_MAX
-# define CONTRACT_CONFIG_OLDOF_MAX 5
+#ifndef BOOST_CONTRACT_CONFIG_OLDOF_MAX
+# define BOOST_CONTRACT_CONFIG_OLDOF_MAX 5
 #endif
#if CONTRACT_CONFIG_OLDOF_MAX > CONTRACT_LIMIT_OLDOFS
# error "CONTRACT_CONFIG_OLDOF_MAX cannot exceed CONTRACT_LIMIT_OLDOFS"
 #endif
 
 /**
@@ -178,8 +178,8 @@
 
 @SeeAlso @RefSect{tutorial, Tutorial} section.
 */
-#ifndef CONTRACT_CONFIG_ARRAY_DIMENSION_MAX
-# define CONTRACT_CONFIG_ARRAY_DIMENSION_MAX 3
+#ifndef BOOST_CONTRACT_CONFIG_ARRAY_DIMENSION_MAX
+# define BOOST_CONTRACT_CONFIG_ARRAY_DIMENSION_MAX 3
 #endif
 
 #ifdef DOXYGEN
@@ -200,7 +200,7 @@
 
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
-#define CONTRACT_CONFIG_DO_NOT_SUBCONTRACT_PRECONDITIONS
+#define BOOST_CONTRACT_CONFIG_DO_NOT_SUBBOOST_CONTRACT_PRECONDITIONS
 
 /**
 @brief Specify that no assertion should be disabled while checking
@@ -220,7 +220,7 @@
 @SeeAlso @RefSect{contract_programming_overview, Contract Programming Overview}
 section.
 */
-#define CONTRACT_CONFIG_PRECONDITIONS_DISABLE_NO_ASSERTION
+#define BOOST_CONTRACT_CONFIG_PRECONDITIONS_DISABLE_NO_ASSERTION
 
 /**
 @brief Report precondition that failed in the overridden function (instead of
@@ -236,7 +236,7 @@
 
 @SeeAlso @RefSect{advanced_topics, Advanced Topics} section.
 */
-#define CONTRACT_CONFIG_REPORT_BASE_PRECONDITION_FAILURE
+#define BOOST_CONTRACT_CONFIG_REPORT_BASE_PRECONDITION_FAILURE
 
 /**
 @brief Make the implementation of this library thread-safe.
@@ -250,7 +250,7 @@
 @SeeAlso @RefSect{contract_programming_overview, Contract Programming Overview}
 section.
 */
-#define CONTRACT_CONFIG_THREAD_SAFE
+#define BOOST_CONTRACT_CONFIG_THREAD_SAFE
 
 #endif // DOXYGEN
 
@@ -152,16 +152,16 @@
 #endif
-#if CONTRACT_CONFIG_OLDOF_MAX > CONTRACT_LIMIT_OLDOFS
-# error "CONTRACT_CONFIG_OLDOF_MAX cannot exceed CONTRACT_LIMIT_OLDOFS"
+#if BOOST_CONTRACT_CONFIG_OLDOF_MAX > BOOST_CONTRACT_LIMIT_OLDOFS
+# error "BOOST_CONTRACT_CONFIG_OLDOF_MAX cannot exceed BOOST_CONTRACT_LIMIT_OLDOFS"
 #endif
 

Modified: sandbox/contract/boost/contract/constructor.hpp
==============================================================================